==> nextcloud-20.0.10.tgz: nextcloud/apps/weather_status/l10n/de.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "Unbekannte Adresse",
    "No result." : "Kein Ergebnis.",
    "Malformed JSON data." : "Fehlerhafte JSON-Daten.",
    "Error" : "Fehler",
    "Weather status" : "Wetterstatus",
    "Weather status in your dashboard" : "Wetterstatus für dein Dashboard",
    "Weather status integrated in the Dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Wetterstatus wird in die Dashboard-App integriert.\nDie Position des Benutzers kann automatisch bestimmt oder manuell definiert werden. Anschließend wird eine 6-Stunden-Vorhersage angezeigt.\nDieser Status kann auch an anderen Stellen wie in der Kalender-App integriert werden.",
    "Detect location" : "Standort ermitteln",
    "Set custom address" : "Benutzerdefinierte Adresse festlegen",
    "Favorites" : "Favoriten",
    "{temperature} {unit} Clear sky at {time}" : "{temperature} {unit} Klarer Himmel um {time}",
    "{temperature} {unit} Cloudy at {time}" : "{temperature} {unit} Bewölkt um {time}",
    "{temperature} {unit} Fair day at {time}" : "{temperature} {unit} Heiterer Tag um {time}",
    "{temperature} {unit} Fair night at {time}" : "{temperature} {unit} Heitere Nacht um {time}",
    "{temperature} {unit} Partly cloudy at {time}" : "{temperature} {unit} Teilweise bewölkt um {time}",
    "{temperature} {unit} Foggy at {time}" : "{temperature} {unit} Nebelig um {time}",
    "{temperature} {unit} Light rain at {time}" : "{temperature} {unit} Leichter Regen um {time}",
    "{temperature} {unit} Rain at {time}" : "{temperature} {unit} Regen um {time}",
    "{temperature} {unit} Heavy rain at {time}" : "{temperature} {unit} Starker Regen um {time}",
    "{temperature} {unit} Rain showers at {time}" : "{temperature} {unit} Regenschauer um {time}",
    "{temperature} {unit} Light rain showers at {time}" : "{temperature} {unit} Leichte Regenschauer um {time}",
    "{temperature} {unit} Heavy rain showers at {time}" : "{temperature} {unit} Starke Regenschauer um {time}",
    "More weather for {adr}" : "Mehr Wetter für {adr}",
    "Loading weather" : "Lade Wetter",
    "Set location for weather" : "Stelle Standort für Wetter ein.",
    "Remove from favorites" : "Von Favoriten entfernen",
    "Add as favorite" : "Als Favorit hinzufügen",
    "You are not logged in." : "Du bist nicht angemeldet.",
    "There was an error getting the weather status information." : "Beim Abrufen der Wetterstatusinformationen ist ein Fehler aufgetreten.",
    "No weather information found" : "Keine Wetterinformationen gefunden",
    "Location not found" : "Standort nicht gefunden",
    "There was an error setting the location address." : "Beim Festlegen der Standortadresse ist ein Fehler aufgetreten.",
    "There was an error setting the location." : "Beim Festlegen des Standortes ist ein Fehler aufgetreten.",
    "There was an error saving the mode." : "Beim Festlegen des Modus ist ein Fehler aufgetreten.",
    "There was an error using personal address." : "Bei der Verwendung der persönlichen Adresse ist ein Fehler aufgetreten.",
    "Weather status integrated in the dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Wetterstatus wird in die Dashboard-App integriert.\nDie Position des Benutzers kann automatisch bestimmt oder manuell definiert werden. Anschließend wird eine 6-Stunden-Vorhersage angezeigt.\nDieser Status kann auch an anderen Stellen wie in der Kalender-App integriert werden."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-20.0.12.tgz: nextcloud/apps/weather_status/l10n/de.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "Unbekannte Adresse",
    "No result." : "Kein Ergebnis.",
    "Malformed JSON data." : "Fehlerhafte JSON-Daten.",
    "Error" : "Fehler",
    "Weather status" : "Wetterstatus",
    "Weather status in your dashboard" : "Wetterstatus für Dein Dashboard",
    "Weather status integrated in the Dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Wetterstatus wird in die Dashboard-App integriert.\nDie Position des Benutzers kann automatisch bestimmt oder manuell definiert werden. Anschließend wird eine 6-Stunden-Vorhersage angezeigt.\nDieser Status kann auch an anderen Stellen wie in der Kalender-App integriert werden.",
    "Detect location" : "Standort ermitteln",
    "Set custom address" : "Benutzerdefinierte Adresse festlegen",
    "Favorites" : "Favoriten",
    "{temperature} {unit} Clear sky at {time}" : "{temperature} {unit} Klarer Himmel um {time}",
    "{temperature} {unit} Cloudy at {time}" : "{temperature} {unit} Bewölkt um {time}",
    "{temperature} {unit} Fair day at {time}" : "{temperature} {unit} Heiterer Tag um {time}",
    "{temperature} {unit} Fair night at {time}" : "{temperature} {unit} Heitere Nacht um {time}",
    "{temperature} {unit} Partly cloudy at {time}" : "{temperature} {unit} Teilweise bewölkt um {time}",
    "{temperature} {unit} Foggy at {time}" : "{temperature} {unit} Nebelig um {time}",
    "{temperature} {unit} Light rain at {time}" : "{temperature} {unit} Leichter Regen um {time}",
    "{temperature} {unit} Rain at {time}" : "{temperature} {unit} Regen um {time}",
    "{temperature} {unit} Heavy rain at {time}" : "{temperature} {unit} Starker Regen um {time}",
    "{temperature} {unit} Rain showers at {time}" : "{temperature} {unit} Regenschauer um {time}",
    "{temperature} {unit} Light rain showers at {time}" : "{temperature} {unit} Leichte Regenschauer um {time}",
    "{temperature} {unit} Heavy rain showers at {time}" : "{temperature} {unit} Starke Regenschauer um {time}",
    "More weather for {adr}" : "Mehr Wetter für {adr}",
    "Loading weather" : "Lade Wetter",
    "Set location for weather" : "Stelle Standort für Wetter ein.",
    "Remove from favorites" : "Von Favoriten entfernen",
    "Add as favorite" : "Als Favorit hinzufügen",
    "You are not logged in." : "Du bist nicht angemeldet.",
    "There was an error getting the weather status information." : "Beim Abrufen der Wetterstatusinformationen ist ein Fehler aufgetreten.",
    "No weather information found" : "Keine Wetterinformationen gefunden",
    "Location not found" : "Standort nicht gefunden",
    "There was an error setting the location address." : "Beim Festlegen der Standortadresse ist ein Fehler aufgetreten.",
    "There was an error setting the location." : "Beim Festlegen des Standortes ist ein Fehler aufgetreten.",
    "There was an error saving the mode." : "Beim Festlegen des Modus ist ein Fehler aufgetreten.",
    "There was an error using personal address." : "Bei der Verwendung der persönlichen Adresse ist ein Fehler aufgetreten.",
    "Weather status integrated in the dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Wetterstatus wird in die Dashboard-App integriert.\nDie Position des Benutzers kann automatisch bestimmt oder manuell definiert werden. Anschließend wird eine 6-Stunden-Vorhersage angezeigt.\nDieser Status kann auch an anderen Stellen wie in der Kalender-App integriert werden."
},
"nplurals=2; plural=(n != 1);");
